# Base URL
Learn about the SAP LeanIX base URL and how to get your subdomain value.
The SAP LeanIX base URL varies among customers. In our documentation, the base URL appears as follows:

```
https://{SUBDOMAIN}.leanix.net
```



**Tip**
You can copy the subdomain value from your workspace URL. If you need help accessing the workspace, contact your workspace administrator.
![Example subdomain in a Workspace URL](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27482d367a44101481c68e6a945220c4_LowRes.png)
Example Subdomain in a Workspace URL
